@@ -247,7 +247,7 @@ class DSMRReader():
         usage_total_high = str(telegram.ELECTRICITY_USED_TARIFF_2.value * 1000),
         redelivery_total_low = str(telegram.ELECTRICITY_DELIVERED_TARIFF_1.value * 1000),
         redelivery_total_high = str(telegram.ELECTRICITY_DELIVERED_TARIFF_2.value * 1000),
-        usage_gas_total = str(telegram.HOURLY_GAS_METER_READING].value.value * 1000)
+        usage_gas_total = str(telegram.HOURLY_GAS_METER_READING.value * 1000)
       )
 
       if self.debug:
